@@ -1,3 +1,3 @@
-from .importer import import_code, import_local_file, import_remote_file, import_gist
+from .importer import import_code, import_gist, import_local_file, import_remote_file
 
 __all__ = ["import_code", "import_local_file", "import_remote_file", "import_gist"]
